local addon = LibStub("AceAddon-3.0"):GetAddon("Ouro Loot",--[[silent=]]true)
if not addon then return end
local plugin = addon:GetModule("CSV",--[[silent=]]true)
if not plugin then return end

-- Help text.  Formatting doesn't matter, but use a blank line to split
-- paragraphs.  This file needs to be edited with a text editor that doesn't
-- do anything stupid by placing extra spaces at the end of lines.

do
local replacement_colors = {
	["+"]="|cff30adff",   -- blue
	["<"]="|cff00ff00",   -- pure green
	[">"]="|r",           -- close formatting
}

local helptext_loot = [=[
+Loot Information Fields>

Add, remove, and rearrange the fields here to suit the needs of whatever
application is reading the data.  Field names are not case sensitive, but
date specifiers (scroll down) are.

Eventually, the code that generates text for each of these tags should be
editable in-game.  For now, see the file "fields.lua" in the plugin folder.

<PlayerName>:  Player receiving the item.

<ItemName>:  Item name without the traditional [square brackets].

<ItemCount>:  Empty, a number, maybe text; need feedback.  Note this only
happens for multiple items in a stack, not "the boss dropped two of the
same gloves".  Currently always a number, even 1.

<Disposition>:  Main spec, offspecs, sent to guild vault, disenchanted.
Currently code names rather than English text.

<DateStamp>:  Most recent dark blue date entry on the main Loot tab, as
formatted by the date/time format option.  Note that sometimes this can
be left in a weird state depending on when/how the CSV modules were loaded;
if you see "Unknown" here, you should probably copy out any changed text
and regenerate the tab.

<Extra>:  Text in the "Note" column if the user entered any directly.
Does NOT include automatically generated text in colors (e.g., "offspec").

]=]

local helptext_raiders = [=[
+Raider Attendance Information Fields>

Add, remove, and rearrange the fields here to suit the needs of whatever
application is reading the data.  Field names are not case sensitive, but
date specifiers (scroll down) are.

Eventually, the code that generates text for each of these tags should be
editable in-game.  For now, see the file "fields.lua" in the plugin folder.

<Boss>:  Name of the encounter.  (what about manual snapshots?)

<PlayerName>:  Self-explanatory.

<Status>:  Fighting, Sitting Out, ...?

<Joined>:  When the player "joined" the raid (see fields.lua for comments)

<Left>:  When the player "left" the raid (see fields.lua for comments)

Are class, level, other demographics, useful here?

]=]

local append_date = [=[
+Fields Involving a Date (or, W-T-F Is Str-F-Time?)>

This can simply be the word <DAY> (all caps, no quotes) to use the date
in a plain format, like "19 May 2007".  No time information will be included.

Alternatively, you can use an arbitrary format string including %-specifiers
in the <strftime> format.  You can see all the specifiers at
<http://is.gd/strftime>, or if you don't like remembering format codes,
use an interactive builder at <http://strftime.net> and paste the result.
For example:

Using <at %I:%M:%S %P on %Y/%m/%d> would give <at 09:52:17 pm on 2007/05/19>

Using <In '%y, the Year of the Cheese Wheel> would give <In '12, the Year
of the Cheese Wheel>

]=]

local function fixup(t)
	return t:gsub ("[%+<>]", replacement_colors)
			:gsub ("([^\n])\n([^\n])", "%1 %2")
			:gsub ("|r\n\n", "|r\n")
end

plugin.helptext_loot = fixup(helptext_loot..append_date)
plugin.helptext_raiders = fixup(helptext_raiders..append_date)

-- To test window sizing, uncomment this line:
--plugin.helptext_loot = ("halp "):rep(1500)
end

-- vim:noet
